diff --git a/target/linux/brcm2708/image/Makefile b/target/linux/brcm2708/image/Makefile
index 6b4cf14..c39becd 100644
--- a/target/linux/brcm2708/image/Makefile
+++ b/target/linux/brcm2708/image/Makefile
@@ -10,6 +10,16 @@ include $(INCLUDE_DIR)/host.mk
 
 define Image/Prepare
 	cp $(LINUX_DIR)/arch/arm/boot/Image $(KDIR)/Image
+	# for the image builder
+	$(CP) \
+		$(BUILD_DIR)/brcm2708-gpu-fw-boot/bootcode.bin \
+		$(BUILD_DIR)/brcm2708-gpu-fw-boot/COPYING.linux \
+		$(BUILD_DIR)/brcm2708-gpu-fw-boot/LICENCE.broadcom \
+		$(BUILD_DIR)/brcm2708-gpu-fw-boot/start.elf \
+		$(BUILD_DIR)/brcm2708-gpu-fw-boot/start_cd.elf \
+		$(BUILD_DIR)/brcm2708-gpu-fw-boot/fixup.dat \
+		$(BUILD_DIR)/brcm2708-gpu-fw-boot/fixup_cd.dat \
+		$(KDIR)/
 endef
 
 FAT32_BLOCK_SIZE=1024
@@ -20,13 +30,13 @@ define Image/Build/RaspberryPi
 
 	mkdosfs $(KDIR)/boot.img -C $(FAT32_BLOCKS)
 	# Raspberry Pi has no bootloader, instead the GPU loads and starts the kernel
-	mcopy -i $(KDIR)/boot.img $(BUILD_DIR)/brcm2708-gpu-fw-boot/bootcode.bin ::
-	mcopy -i $(KDIR)/boot.img $(BUILD_DIR)/brcm2708-gpu-fw-boot/COPYING.linux ::
-	mcopy -i $(KDIR)/boot.img $(BUILD_DIR)/brcm2708-gpu-fw-boot/LICENCE.broadcom ::
-	mcopy -i $(KDIR)/boot.img $(BUILD_DIR)/brcm2708-gpu-fw-boot/start.elf ::
-	mcopy -i $(KDIR)/boot.img $(BUILD_DIR)/brcm2708-gpu-fw-boot/start_cd.elf ::
-	mcopy -i $(KDIR)/boot.img $(BUILD_DIR)/brcm2708-gpu-fw-boot/fixup.dat ::
-	mcopy -i $(KDIR)/boot.img $(BUILD_DIR)/brcm2708-gpu-fw-boot/fixup_cd.dat ::
+	mcopy -i $(KDIR)/boot.img $(KDIR)/bootcode.bin ::
+	mcopy -i $(KDIR)/boot.img $(KDIR)/COPYING.linux ::
+	mcopy -i $(KDIR)/boot.img $(KDIR)/LICENCE.broadcom ::
+	mcopy -i $(KDIR)/boot.img $(KDIR)/start.elf ::
+	mcopy -i $(KDIR)/boot.img $(KDIR)/start_cd.elf ::
+	mcopy -i $(KDIR)/boot.img $(KDIR)/fixup.dat ::
+	mcopy -i $(KDIR)/boot.img $(KDIR)/fixup_cd.dat ::
 	mcopy -i $(KDIR)/boot.img cmdline.txt ::
 	mcopy -i $(KDIR)/boot.img config.txt ::
 	mcopy -i $(KDIR)/boot.img $(KDIR)/Image ::kernel.img  # Copy OpenWrt built kernel
@@ -34,11 +44,18 @@ define Image/Build/RaspberryPi
 		$(CONFIG_BRCM2708_SD_BOOT_PARTSIZE) $(CONFIG_TARGET_ROOTFS_PARTSIZE)
 endef
 
+define Image/Build/gzip/RaspberryPi
+    gzip -f9 $(BIN_DIR)/$(IMG_PREFIX)-$(1)
+endef
+
 define Image/Build
 	$(CP) $(KDIR)/root.$(1) $(BIN_DIR)/$(IMG_PREFIX)-$(1).img
+	$(call Image/Build/gzip/RaspberryPi,$(1).img)
 	$(CP) $(KDIR)/Image $(BIN_DIR)/$(IMG_PREFIX)-Image
+	$(call Image/Build/gzip/RaspberryPi,Image)
 
 	$(call Image/Build/RaspberryPi,$(1))
+	$(call Image/Build/gzip/RaspberryPi,sdcard-vfat-$(1).img)
 endef
 
 $(eval $(call BuildImage))
